Blaeu, creating measurements on RIPE Atlas probes
=================================================

This is a set of `Python <https://www.python.org/>`__ programs to start
distributed Internet measurements on the network of `RIPE Atlas
probes <https://atlas.ripe.net/>`__, and to analyze their results.

For installation, you can use usual Python tools, for instance:

::

    pip3 install blaeu

You may also be interested by `my article at RIPE
Labs <https://labs.ripe.net/Members/stephane_bortzmeyer/using-ripe-atlas-to-debug-network-connectivity-problems>`__,
although the tools' installation method and names are now different.

Blaeu requires Python 3.

Note that `the old
version <https://github.com/RIPE-Atlas-Community/ripe-atlas-community-contrib>`__
ran on Python 2 but is no longer maintained.

Name
----

It comes from the `famous Dutch
cartographer <https://en.wikipedia.org/wiki/Willem_Blaeu>`__.

Reference site
--------------

`On FramaGit <https://framagit.org/bortzmeyer/blaeu>`__

Author
------

Stéphane Bortzmeyer stephane+frama@bortzmeyer.org
